==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/tr-TR/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Bu kullanıcı giriş yapabilir',
    'activated_disabled_help_text' => 'Kendi hesabınız için aktivasyon durumunu düzenleyemezsiniz.',
    'assets_user'       => 'Demirbaşlar şu kişiye atandı :name',
    'bulk_update_warn'	=> ': user_count Kullanıcının özelliklerini düzenlemek üzeresiniz. Lütfen, bu formu kullanarak kendi kullanıcı özniteliklerini değiştiremeyeceğinizi ve kendi kullanıcılarınız için ayrı ayrı düzenlemeler yapmanız gerektiğini unutmayın.',
    'bulk_update_help'	=> 'Bu form, birden fazla kullanıcıyı bir kerede güncellemenize olanak tanır. Sadece değiştirmek istediğiniz alanları doldurun. Boş bırakılan alanlar değişmeden kalır.',
    'current_assets'    => 'Şu anda bu kullanıcıya atanmış varlıklar',
    'clone'             => 'Kullanıcıyı Kopyala',
    'contact_user'      => 'İlgili Kişi :name',
    'edit'              => 'Kullanıcıyı Düzenle',
    'filetype_info'     => 'İzin verilen dosya türleri; png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, rar.',
    'history_user'      => ':name Kişisi ile iligli geçmiş',
    'info'				=> 'Bilgi',
    'restore_user'		=> 'Onları geri yüklemek için buraya tıklayın.',
    'last_login'        => 'Son oturum açma tarihi',
    'ldap_config_text'  => 'LDAP yapılandırma ayarları Yönetici> Ayarlar\'da bulunabilir. Seçilen yer (isteğe bağlı), tüm içe aktarılan kullanıcılar için ayarlanır.',
    'print_assigned'    => 'Atananların Tümünü Yazdır',
    'email_assigned'    => 'Tüm Atananların E-posta Listesi',
    'user_notified'     => 'Kullanıcıya, atanmış nesnelerinin bir listesi e-posta ile gönderildi.',
    'auto_assign_label' => 'Uygun lisansları otomatik olarak atarken bu kullanıcıyı dahil edin',
    'auto_assign_help'  => 'Lisansların otomatik atanmasında bu kullanıcıyı atla',
    'software_user'     => 'Yazılıma :name için çıkış yapılmış',
    'send_email_help'   => 'Bu kullanıcıya kimlik bilgilerini gönderebilmesi için bir e-posta adresi sağlamalısınız. E-posta kimlik bilgileri yalnızca kullanıcı oluşturulurken yapılabilir. Parolalar tek yönlü bir karmada saklanır ve bir kez kaydedildikten sonra geri alınamaz.',
    'view_user'         => 'Kullanıcıyı Görüntüle :name',
    'usercsv'           => 'CSV Dosyası',
    'two_factor_admin_optin_help' => 'Mevcut yönetici ayarlarınız, iki aşamalı kimlik doğrulamasının seçici olarak uygulanmasına izin verir.  ',
    'two_factor_enrolled' => 'Kayıtlı 2FA Cihazı ',
    'two_factor_active'   => '2FA Etkin ',
    'user_deactivated'  => 'Kullanıcı oturum açamıyor',
    'user_activated'  => 'Kullanıcı oturum açabilir',
    'activation_status_warning' => 'Aktivasyon durumunu değiştirme',
    'group_memberships_helpblock' => 'Yalnızca süper yöneticiler grup üyeliklerini düzenleyebilir.',
    'superadmin_permission_warning' => 'Yalnızca süper yöneticiler bir kullanıcıya süper yönetici erişimi verebilir.',
    'admin_permission_warning' => 'Yalnızca yönetici haklarına veya daha fazlasına sahip kullanıcılar, bir kullanıcıya yönetici erişimi verebilir.',
    'remove_group_memberships' => 'Grup Üyeliklerini Kaldır',
    'warning_deletion_information' => 'Aşağıda listelenen :sayılan kullanıcı(lar) daki TÜM öğeleri kontrol etmek üzeresiniz. Süper yönetici adları kırmızıyla vurgulanır.',
    'update_user_assets_status' => 'Bu kullanıcılar için tüm varlıkları bu duruma güncelleyin',
    'checkin_user_properties' => 'Bu kullanıcılarla ilişkili tüm mülkleri kontrol edin',
    'remote_label'   => 'Bu uzak bir kullanıcı',
    'remote'   => 'Uzaktan Kumanda',
    'remote_help' => 'Bu, fiziksel konumlarınıza hiç gelmeyen veya nadiren gelen uzak kullanıcılara göre filtrelemeniz gerektiğinde yararlı olabilir.',
    'not_remote_label' => 'Bu uzak bir kullanıcı değil',
    'vip_label' => 'VIP kullanıcı',
    'vip_help' => 'Organizasyonunuzdaki kişileri özel bir şekilde belirtmek, işaretlemek istiyor iseniz bu yardımcı olabilir.',
    'create_user' => 'Kullanıcı oluştur',
    'create_user_page_explanation' => 'Siteye ilk kez giriş yapacağınızda kullanacağınız hesap bilgisidir.',
    'email_credentials' => 'E-posta kimlik bilgileri',
    'email_credentials_text' => 'Kimlik bilgilerimi yukarıdaki e-posta adresine e-postayla gönder',
    'next_save_user' => 'Sonraki: Kullanıcıyı Kaydet',
    'all_assigned_list_generation' => 'Bu tarihinde oluşturuldu:',
    'email_user_creds_on_create' => 'Bu kullanıcıya kimlik bilgileri e-postayla gönderilsin mi?',
];

==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/tr-TR/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Bu kullanıcı giriş yapabilir',
    'activated_disabled_help_text' => 'Kendi hesabınız için aktivasyon durumunu düzenleyemezsiniz.',
    'assets_user'       => 'Demirbaşlar şu kişiye atandı :name',
    'bulk_update_warn'	=> ': user_count Kullanıcının özelliklerini düzenlemek üzeresiniz. Lütfen, bu formu kullanarak kendi kullanıcı özniteliklerini değiştiremeyeceğinizi ve kendi kullanıcılarınız için ayrı ayrı düzenlemeler yapmanız gerektiğini unutmayın.',
    'bulk_update_help'	=> 'Bu form, birden fazla kullanıcıyı bir kerede güncellemenize olanak tanır. Sadece değiştirmek istediğiniz alanları doldurun. Boş bırakılan alanlar değişmeden kalır.',
    'current_assets'    => 'Şu anda bu kullanıcıya atanmış varlıklar',
    'clone'             => 'Kullanıcıyı Kopyala',
    'contact_user'      => 'İlgili Kişi :name',
    'edit'              => 'Kullanıcıyı Düzenle',
    'filetype_info'     => 'İzin verilen dosya türleri; png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, rar.',
    'history_user'      => ':name Kişisi ile iligli geçmiş',
    'info'				=> 'Bilgi',
    'restore_user'		=> 'Onları geri yüklemek için buraya tıklayın.',
    'last_login'        => 'Son oturum açma tarihi',
    'ldap_config_text'  => 'LDAP yapılandırma ayarları Yönetici> Ayarlar\'da bulunabilir. Seçilen yer (isteğe bağlı), tüm içe aktarılan kullanıcılar için ayarlanır.',
    'print_assigned'    => 'Atananların Tümünü Yazdır',
    'email_assigned'    => 'Tüm Atananların E-posta Listesi',
    'user_notified'     => 'Kullanıcıya, atanmış nesnelerinin bir listesi e-posta ile gönderildi.',
    'users_notified'    => 'The user has been emailed a list of their currently assigned items.|:count users have been emailed a list of their currently assigned items.',
    'users_notified_warning' => ':count user has been emailed a list of their currently assigned items, however :no_email users did not have an email address so could not be emailed.|:count users have been emailed a list of their currently assigned items, however :no_email user(s) did not have an email address so could not be emailed.',
    'auto_assign_label' => 'Uygun lisansları otomatik olarak atarken bu kullanıcıyı dahil edin',
    'auto_assign_help'  => 'Lisansların otomatik atanmasında bu kullanıcıyı atla',
    'software_user'     => 'Yazılıma :name için çıkış yapılmış',
    'send_email_help'   => 'Bu kullanıcıya kimlik bilgilerini gönderebilmesi için bir e-posta adresi sağlamalısınız. E-posta kimlik bilgileri yalnızca kullanıcı oluşturulurken yapılabilir. Parolalar tek yönlü bir karmada saklanır ve bir kez kaydedildikten sonra geri alınamaz.',
    'view_user'         => 'Kullanıcıyı Görüntüle :name',
    'usercsv'           => 'CSV Dosyası',
    'two_factor_admin_optin_help' => 'Mevcut yönetici ayarlarınız, iki aşamalı kimlik doğrulamasının seçici olarak uygulanmasına izin verir.  ',
    'two_factor_enrolled' => 'Kayıtlı 2FA Cihazı ',
    'two_factor_active'   => '2FA Etkin ',
    'user_deactivated'  => 'Kullanıcı oturum açamıyor',
    'user_activated'  => 'Kullanıcı oturum açabilir',
    'activation_status_warning' => 'Aktivasyon durumunu değiştirme',
    'group_memberships_helpblock' => 'Yalnızca süper yöneticiler grup üyeliklerini düzenleyebilir.',
    'superadmin_permission_warning' => 'Yalnızca süper yöneticiler bir kullanıcıya süper yönetici erişimi verebilir.',
    'admin_permission_warning' => 'Yalnızca yönetici haklarına veya daha fazlasına sahip kullanıcılar, bir kullanıcıya yönetici erişimi verebilir.',
    'remove_group_memberships' => 'Grup Üyeliklerini Kaldır',
    'warning_deletion_information' => 'Aşağıda listelenen :sayılan kullanıcı(lar) daki TÜM öğeleri kontrol etmek üzeresiniz. Süper yönetici adları kırmızıyla vurgulanır.',
    'update_user_assets_status' => 'Bu kullanıcılar için tüm varlıkları bu duruma güncelleyin',
    'checkin_user_properties' => 'Bu kullanıcılarla ilişkili tüm mülkleri kontrol edin',
    'remote_label'   => 'Bu uzak bir kullanıcı',
    'remote'   => 'Uzaktan Kumanda',
    'remote_help' => 'Bu, fiziksel konumlarınıza hiç gelmeyen veya nadiren gelen uzak kullanıcılara göre filtrelemeniz gerektiğinde yararlı olabilir.',
    'not_remote_label' => 'Bu uzak bir kullanıcı değil',
    'vip_label' => 'VIP kullanıcı',
    'vip_help' => 'Organizasyonunuzdaki kişileri özel bir şekilde belirtmek, işaretlemek istiyor iseniz bu yardımcı olabilir.',
    'create_user' => 'Kullanıcı oluştur',
    'create_user_page_explanation' => 'Siteye ilk kez giriş yapacağınızda kullanacağınız hesap bilgisidir.',
    'email_credentials' => 'E-posta kimlik bilgileri',
    'email_credentials_text' => 'Kimlik bilgilerimi yukarıdaki e-posta adresine e-postayla gönder',
    'next_save_user' => 'Sonraki: Kullanıcıyı Kaydet',
    'all_assigned_list_generation' => 'Bu tarihinde oluşturuldu:',
    'email_user_creds_on_create' => 'Bu kullanıcıya kimlik bilgileri e-postayla gönderilsin mi?',
];
